@@ -162,7 +162,7 @@ B<idl2pyext> parses the given input file (IDL) and generates :
 =over 4
 
 =item *
-a set of Python sources : an optional _I<spec>.py 
+a set of Python sources : an optional _I<spec>.py
 and I<pkg>/__init__.py for each package (in a standard tree)
 
 =item *
@@ -189,8 +189,8 @@ The parser is generated by Parse::Yapp.
 
 B<idl2pyext> needs a B<cpp> executable.
 
-CORBA Specifications, including IDL (Interface Language Definition) 
-C Language Mapping and Python Language Mapping 
+CORBA Specifications, including IDL (Interface Language Definition)
+C Language Mapping and Python Language Mapping
 are available on E<lt>http://www.omg.org/E<gt>.
 
 =head1 INSTALLATION
@@ -199,7 +199,7 @@ After standard Perl installation, you must install the Python package PyIDL :
 
     setup.py install
 
-And copy the file F<corba.h> in Python24/include. 
+And copy the file F<corba.h> in Python24/include.
 
 =head1 TUTORIAL
 
@@ -213,9 +213,9 @@ Nota : the IDL interface Calc is in the global scope.
 
 First, copy additional files in current directory
 
-    cp ../corba.h
-    cp ../corba.c
-    cp ../cpyhelper.c
+    cp ../corba/corba.h
+    cp ../corba/corba.c
+    cp ../corba/cpyhelper.c
 
 Second, run :
 
